@@ -43,6 +43,7 @@ from pyramid.authorization import ACLHelper
 from pyramid.authorization import Authenticated
 from pyramid.authorization import Everyone
 
+from pyramid_helpers.utils import ConfigurationError
 from pyramid_helpers.utils import get_settings
 from pyramid_helpers.utils import request_cache
 from pyramid_helpers.utils import resolve_dotted
@@ -169,7 +170,7 @@ class MultiSecurityPolicy:
 
         for policy in policies:
             if policy not in self.POLICIES:
-                raise Exception('[AUTH] Invalid policy: {0}'.format(policy))
+                raise ConfigurationError('[AUTH] Invalid policy: {0}'.format(policy))
 
         self.cookie = AuthTktCookieHelper(secret, hashalg=hashalg) if 'ticket' in policies else None
         self.policies = policies
@@ -428,36 +429,36 @@ def parse_settings(settings, include_defaults=True):
     else:
         for policy in settings['auth']['policies']:
             if policy not in MultiSecurityPolicy.POLICIES:
-                raise Exception('[AUTH] Invalid policy for parameters policies in section [auth]: {0}'.format(policy))
+                raise ConfigurationError('[AUTH] Invalid policy for parameters policies in section [auth]: {0}'.format(policy))
 
     # Check mode
     if settings['auth']['mode'] is None:
-        raise Exception('[AUTH] Missing value for parameter mode in section [auth]')
+        raise ConfigurationError('[AUTH] Missing value for parameter mode in section [auth]')
 
     if settings['auth']['mode'] not in AUTH_CLIENTS:
-        raise Exception('[AUTH] Invalid value for parameter mode in section [auth]: {0}'.format(settings['auth']['mode']))
+        raise ConfigurationError('[AUTH] Invalid value for parameter mode in section [auth]: {0}'.format(settings['auth']['mode']))
 
     # Check hashalg
     if settings['policy:ticket']['hashalg'] not in hashlib.algorithms_available:
-        raise Exception('[AUTH] Invalid value for parameter hashalg in section [policy:ticket]: {0}'.format(settings['auth']['policy:ticket']['hashalg']))
+        raise ConfigurationError('[AUTH] Invalid value for parameter hashalg in section [policy:ticket]: {0}'.format(settings['auth']['policy:ticket']['hashalg']))
 
     # Resolve get_principals
     func = resolve_dotted(settings['auth']['get_principals'])
     if func is None:
-        raise Exception('[AUTH] Invalid value for parameter get_principals in section [auth]: {0}'.format(settings['auth']['get_principals']))
+        raise ConfigurationError('[AUTH] Invalid value for parameter get_principals in section [auth]: {0}'.format(settings['auth']['get_principals']))
     settings['auth']['get_principals'] = func
 
     # Resolve get_user_by_username
     func = resolve_dotted(settings['auth']['get_user_by_username'])
     if func is None:
-        raise Exception('[AUTH] Invalid value for parameter get_user_by_username in section [auth]: {0}'.format(settings['auth']['get_user_by_username']))
+        raise ConfigurationError('[AUTH] Invalid value for parameter get_user_by_username in section [auth]: {0}'.format(settings['auth']['get_user_by_username']))
     settings['auth']['get_user_by_username'] = func
 
     # Resolve get_username_by_token if needed
     if 'token' in settings['auth']['policies']:
         func = resolve_dotted(settings['policy:token']['get_username_by_token'])
         if func is None:
-            raise Exception('[AUTH] Invalid value for parameter get_username_by_token in section [policy:token]: {0}'.format(settings['auth']['get_username_by_token']))
+            raise ConfigurationError('[AUTH] Invalid value for parameter get_username_by_token in section [policy:token]: {0}'.format(settings['auth']['get_username_by_token']))
         settings['policy:token']['get_username_by_token'] = func
 
     return settings
@@ -479,7 +480,7 @@ def includeme(config):
     # Load an parse settings
     settings = get_settings(config, 'auth')
     if settings is None:
-        raise Exception('[AUTH] Invalid or missing configuration for AUTH, please check auth.filepath directive')
+        raise ConfigurationError('[AUTH] Invalid or missing configuration for AUTH, please check auth.filepath directive')
 
     settings = parse_settings(settings)
 
