@@ -84,7 +84,7 @@ def build_search_query(sort='id', order='asc', **criteria):
 def create_or_modify(request, form, article=None):
     """ Create or modify function """
 
-    _ = request.translate
+    translate = request.translate
 
     if form.errors:
         return None
@@ -92,7 +92,7 @@ def create_or_modify(request, form, article=None):
     # Check title unicity
     same_title = DBSession.query(Article).filter_by(title=form.result['title']).first()
     if same_title and same_title != article:
-        form.errors['title'] = _('Title already used in another article')
+        form.errors['title'] = translate('Title already used in another article')
         return None
 
     # Do the job
