@@ -28,6 +28,8 @@ from babel.dates import format_date as format_date_
 from babel.dates import format_time as format_time_
 from babel.numbers import format_decimal as format_decimal_
 
+from pyramid_helpers.utils import deprecated
+
 
 def N_(tstring):
     """ Dummy translation function """
@@ -35,19 +37,27 @@ def N_(tstring):
 
 
 def add_renderer_globals(event):
-    """ Add _() function to renderer context """
+    """ Add I18n functions to renderer context """
+
     request = event['request']
-    event['_'] = request.translate
-    event['ungettext'] = request.pluralize
+
     event['localizer'] = request.localizer
+    event['pluralize'] = request.pluralize
+    event['translate'] = request.translate
+
     event['format_date'] = request.format_date
     event['format_datetime'] = request.format_datetime
     event['format_decimal'] = request.format_decimal
     event['format_time'] = request.format_time
 
+    # Add deprecated functions
+    event['_'] = deprecated('_', request.translate, new_name='translate')
+    event['ungettext'] = deprecated('ungettext', request.pluralize, new_name='pluralize')
+
 
 def add_localizer(event):
-    """ Add localizer to request """
+    """ Add I18n functions to request """
+
     request = event.request
     registry = request.registry
     settings = registry.settings or {}
