@@ -40,6 +40,7 @@ import ldap.controls
 import ldap.modlist
 
 from pyramid_helpers.auth import AuthenticationClient
+from pyramid_helpers.utils import ConfigurationError
 from pyramid_helpers.utils import get_settings
 
 
@@ -435,13 +436,13 @@ def includeme(config):
     # Load and parse settings
     settings = get_settings(config, 'ldap')
     if settings is None:
-        raise Exception('[LDAP] Invalid or missing configuration for LDAP, please check ldap.filepath directive')
+        raise ConfigurationError('[LDAP] Invalid or missing configuration for LDAP, please check ldap.filepath directive')
 
     settings = parse_settings(settings)
 
     # Connection
     if settings['ldap']['uri'] is None:
-        raise Exception('[LDAP] Missing uri parameter in configuration')
+        raise ConfigurationError('[LDAP] Missing uri parameter in configuration')
 
     # Cache setup
     cache_params = parse_cache_config_options(dict(
