@@ -40,6 +40,7 @@ from pyrad.packet import AccessAccept
 from pyrad.packet import AccessRequest
 
 from pyramid_helpers.auth import AuthenticationClient
+from pyramid_helpers.utils import ConfigurationError
 from pyramid_helpers.utils import get_settings
 
 
@@ -223,7 +224,7 @@ def includeme(config):
     # Load and parse settings
     settings = get_settings(config, 'radius')
     if settings is None:
-        raise Exception('[RADIUS] Invalid or missing configuration for RADIUS, please check radius.filepath directive')
+        raise ConfigurationError('[RADIUS] Invalid or missing configuration for RADIUS, please check radius.filepath directive')
 
     settings = parse_settings(settings)
 
@@ -237,7 +238,7 @@ def includeme(config):
             try:
                 data['oid'] = int(section[5:])
             except ValueError as exc:
-                raise Exception(f'[RADIUS] Invalid attribute definition for {section} in configuration') from exc
+                raise ConfigurationError(f'[RADIUS] Invalid attribute definition for {section} in configuration') from exc
 
             attributes.append(data)
 
@@ -251,7 +252,7 @@ def includeme(config):
             servers.append(data)
 
     if not servers:
-        raise Exception('[RADIUS] Empty or invalid configuration for server entries in configuration')
+        raise ConfigurationError('[RADIUS] Empty or invalid configuration for server entries in configuration')
 
     # Prepare arguments
     kwargs = settings['radius'].copy()
