@@ -199,12 +199,23 @@ $(function() {
             var description = $card.find('span.service-description').text().toLowerCase();
 
             if (path.match(regex) || description.match(regex)) {
-                $card.show();
+                $card.removeClass('hidden');
             }
             else {
-                $card.hide();
+                $card.addClass('hidden');
             }
-       });
+        });
+
+        $.each($('.module-title'), function(i, title) {
+            var $title = $(title);
+            var $group = $title.next();
+            if ($group.children('.hidden').length != $group.children().length) {
+                $title.removeClass('hidden');
+            }
+            else {
+                $title.addClass('hidden');
+            }
+        });
     }).trigger('change');
 
     // Pre-compile form error template
